@@ -3,44 +3,45 @@ package Coro::PatchSet::Handle;
 use strict;
 use Coro::Handle;
 
-our $VERSION = '0.06_2';
+our $VERSION = '0.01';
 
-package # hide it from cpan
-	Coro::Handle::FH;
+{
+	package Coro::Handle::FH;
+	
+	sub READ {
+		my $len = $_[2];
+		my $ofs = $_[3];
+		my $res;
 
-sub READ {
-	my $len = $_[2];
-	my $ofs = $_[3];
-	my $res;
-
-	# first deplete the read buffer
-	if (length $_[0][3]) {
-		my $l = length $_[0][3];
+		# first deplete the read buffer
+		if (length $_[0][3]) {
+			my $l = length $_[0][3];
+			
+			if ($l <= $len) {
+				substr ($_[1], $ofs) = $_[0][3]; $_[0][3] = "";
+				return $l;
+			} else {
+				substr ($_[1], $ofs) = substr ($_[0][3], 0, $len);
+				substr ($_[0][3], 0, $len) = "";
+				return $len;
+			}
+		}
 		
-		if ($l <= $len) {
-			substr ($_[1], $ofs) = $_[0][3]; $_[0][3] = "";
-			return $l;
-		} else {
-			substr ($_[1], $ofs) = substr ($_[0][3], 0, $len);
-			substr ($_[0][3], 0, $len) = "";
-			return $len;
+		while() {
+			my $r = sysread $_[0][0], $_[1], $len, $ofs;
+			if (defined $r) {
+				$len -= $r;
+				$ofs += $r;
+				$res += $r;
+				last;
+			} elsif ($! != EAGAIN && $! != EINTR && $! != WSAEWOULDBLOCK) {
+				last;
+			}
+			last if $_[0][8] || !&readable;
 		}
+		
+		$res
 	}
-	
-	while() {
-		my $r = sysread $_[0][0], $_[1], $len, $ofs;
-		if (defined $r) {
-			$len -= $r;
-			$ofs += $r;
-			$res += $r;
-			last;
-		} elsif ($! != EAGAIN && $! != EINTR && $! != WSAEWOULDBLOCK) {
-			last;
-		}
-		last if $_[0][8] || !&readable;
-	}
-	
-	$res
 }
 
 1;
@@ -72,7 +73,7 @@ for 10 minutes (or until error/socket closing). But this behaviour is not compat
 which Coro::Handle tries to emulate. After this patch sysread will behave like sysread on system sockets. It will read
 >= 1 and <= $len bytes for you. Bytes readed count may be less than $len if sysread() may not read it without blocking.
 But will always be >= 1 (if there was no error or socket closing). So in the situation above sysread will read $len-1
-bytes and return. See t/05_handle_read.t
+bytes and return.
 
 =head1 SEE ALSO
 
